@@ -122,12 +122,6 @@ def get_local_files( redid_config, where ):
 	return files
 	
 
-# Extra mappings for special Redid formats
-redid_type_map = {
-	'.9.png': 'image/x-redid-9patch',
-	'.gradient.yaml': 'image/x-redid-gradient',
-}
-
 def get_file_type( redid_config, filename ):
 	"""
 		Determine the type of the file, and it's basename (less extensions as appropriate)
@@ -143,19 +137,7 @@ def get_file_type( redid_config, filename ):
 			break
 	
 	if ct == None:
-		for k, v in redid_type_map.iteritems():
-			if filename.endswith( k ):
-				ct = v
-				ext = k
-				break
-
-	if ct == None:
-		base, ext = os.path.splitext( filename )
-		ct, enc = mimetypes.guess_type( filename, strict = False )
-
-	if ct == None:
-		ct = 'application/octet-stream'
-		# ext set from previous if
+		ct, ext = common.guess_mime_type( filename )
 	
 	# strip extension of image types, to match server handling
 	if ct.startswith( 'image/' ):
